Reciprocal
==========

A library for building simple interactive console menus for UNIX-based systems. It depends on [click](https://github.com/pallets/click) for console utilities.

## Installation

```bash
pip install reciprocal
```

## Examples
See [examples](/examples) for some usage examples.
